# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2017-06-06 19:28
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('maas', '0002_auto_20170606_1857'),
    ]

    operations = [
        migrations.AddField(
            model_name='mail',
            name='delivered',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='mail',
            name='sender_title',
            field=models.CharField(default='', max_length=200),
        ),
    ]
