# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2017-06-06 18:57
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('maas', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='mail',
            name='body',
            field=models.TextField(default='', max_length=5000),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='mail',
            name='recipient',
            field=models.EmailField(default='test@test.com', max_length=254),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='mail',
            name='sender',
            field=models.EmailField(default='test@test.com', max_length=254),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='mail',
            name='subject',
            field=models.CharField(default='', max_length=200),
            preserve_default=False,
        ),
    ]
