# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2017-06-06 20:17
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('maas', '0003_auto_20170606_1928'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='mail',
            options={'verbose_name_plural': 'Mail'},
        ),
        migrations.AddField(
            model_name='mail',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, default='1970-01-01 00:00:00'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='mail',
            name='updated_at',
            field=models.DateTimeField(auto_now=True),
        ),
        migrations.AlterField(
            model_name='mail',
            name='sender_title',
            field=models.CharField(blank=True, default='', max_length=200, null=True),
        ),
    ]
